@@ -73,7 +73,7 @@ var createServer = exports.createServer = function (client, options, callback) {
       // if the HostedService does not exist, create it
       vmOptions.hostedService = service;
       if (vmOptions.hostedService === null) {
-        createHostedService(client, options.name, function (err, service) {
+        createHostedService(client, options, function (err, service) {
           if (err) {
             next(err);
           } else {
@@ -97,19 +97,11 @@ var createServer = exports.createServer = function (client, options, callback) {
       });
     },
     function (next) {
-      ssh = client.config.azure.ssh;
-      if (!ssh) {
-        next(null);
-        return;
+      ssh = options.ssh;
+      if (ssh) {
+        vmOptions.sshCertInfo = cert.getAzureCertInfo(ssh.cert);
       }
-      cert.getAzureCert(ssh.pem,function (err, info) {
-        if (err) {
-          next(err);
-        } else {
-          vmOptions.sshCertInfo = info;
-          next(null);
-        }
-      });
+      next();
     },
     function (next) {
       // add the ssh certificate to the service
@@ -163,7 +155,7 @@ var createEndpoints = function (ports) {
   var endPoints = '',
     template = templates.loadSync('endpoint.xml');
 
-  ports.forEach(function (port) {
+  (ports || []).forEach(function (port) {
     endPoints += templates.compileSync(template,port);
   });
   return endPoints;
@@ -177,13 +169,13 @@ var createLinuxVM = function (client, options, vmOptions, callback) {
   var configParams = {
     NAME: options.name,
     LABEL_BASE64: label,
-    USERNAME: client.config.azure.username,
-    PASSWORD: client.config.azure.password,
+    USERNAME: options.username,
+    PASSWORD: options.password,
     SSH_CERTIFICATE_FINGERPRINT: vmOptions.sshCertInfo.fingerprint,
-    PORT: client.config.azure.ssh.port || '22',
-    LOCAL_PORT: client.config.azure.ssh.localPort || '22',
+    PORT: options.ssh.port || '22',
+    LOCAL_PORT: options.ssh.localPort || '22',
     ROLESIZE: options.flavor,
-    ENDPOINTS: createEndpoints(client.config.azure.ports),
+    ENDPOINTS: createEndpoints(options.ports),
     OS_SOURCE_IMAGE_NAME: vmOptions.image.Name,
     OS_IMAGE_MEDIALINK: mediaLink
   };
@@ -198,11 +190,11 @@ var createWindowsVM = function (client, options, vmOptions, callback) {
 
   var configParams = {
     NAME: options.name,
-    COMPUTER_NAME: client.config.azure.computerName || options.name.slice(0, 15),
+    COMPUTER_NAME: options.computerName || options.name.slice(0, 15),
     LABEL_BASE64: label,
-    PASSWORD: client.config.azure.password,
+    PASSWORD: options.password,
     ROLESIZE: options.flavor,
-    ENDPOINTS: createEndpoints(client.config.azure.ports),
+    ENDPOINTS: createEndpoints(options.ports),
     OS_SOURCE_IMAGE_NAME: vmOptions.image.Name,
     OS_IMAGE_MEDIALINK: mediaLink
   };
@@ -242,7 +234,7 @@ var validateCreateOptions = function (options, config, callback) {
   options = options || {}; // no args
 
   // check required options values
-  ['flavor', 'image', 'name'].forEach(function (member) {
+  ['flavor', 'image', 'name', 'username', 'password', 'location'].forEach(function (member) {
     if (!options[member]) {
       errs.handle(
         errs.create({ message: 'options.' + member + ' is a required argument.' }),
@@ -250,16 +242,7 @@ var validateCreateOptions = function (options, config, callback) {
       );
     }
   });
-
-  ['username', 'password', 'location'].forEach(function (member) {
-    if (!config.azure[member]) {
-      errs.handle(
-        errs.create({ message: 'config.azure.' + member + ' is a required azure config parameter.' }),
-        callback
-      );
-    }
-  });
-  callback(null);
+  callback();
 };
 
 /**
@@ -324,12 +307,12 @@ var makeTemplateRequest = function (client, path, templateName, params, callback
   );
 };
 
-var createHostedService = exports.createHostedService = function (client, serviceName, callback) {
+var createHostedService = exports.createHostedService = function (client, options, callback) {
   var path = client.subscriptionId + '/services/hostedservices';
   var params = {
-    NAME: serviceName,
-    LABEL_BASE64: new Buffer(serviceName).toString('base64'),
-    LOCATION: client.config.azure.location
+    NAME: options.name,
+    LABEL_BASE64: new Buffer(options.name).toString('base64'),
+    LOCATION: options.location
   };
 
   makeTemplateRequest(client, path, 'createHostedService.xml', params, callback);
