@@ -62,12 +62,6 @@ Bootstrapper.prototype.readKeys = function (callback) {
   // Helper function which populates a given field (`public`, `private`)
   // in the keys info to be returned.
   //
-  //TODO: we need to clean up this code to handle other types of ssh keypairs like pem files on azure
-  // perhaps key options should state which file is public/private so we don't
-  // depend on .pub extension.
-  // For example...
-  // "keypair" : {"public" : "/path/to/public/file", "private" : "/path/to/private/file" }
-
   function readKey (key, next) {
     var keytype = path.extname(key) === '.pub' ? 'public' : 'private';
     fs.readFile(key, function (err, data) {
@@ -85,10 +79,23 @@ Bootstrapper.prototype.readKeys = function (callback) {
       next();
     });
   }
+  //
+  // Helper function to iterate the array of keys
+  //
+  function iterateKeys (keys) {
+    async.forEach(keys, readKey, function (err) {
+      return err ? callback(err) : callback(null, keyinfo);
+    });
+  }
+  //
+  // Logic to interpret if this.keys are an array or an object
+  //
+  if (this.keys instanceof Array) {
+    iterateKeys(this.keys);
+  } else if (this.keys.hasOwnProperty('public') && this.keys.hasOwnProperty('private')) {
+    iterateKeys([this.keys.public, this.keys.private]);
+  }
 
-  async.forEach(this.keys, readKey, function (err) {
-    return err ? callback(err) : callback(null, keyinfo);
-  });
 };
 
 //
@@ -611,12 +618,12 @@ Bootstrapper.prototype._createServer = function (options) {
 //
 Bootstrapper.prototype._tunnel = function (argv, options) {
   var user = (
-    (options.tunnel.user 
-      || options.remoteUser 
+    (options.tunnel.user
+      || options.remoteUser
       || this.remoteUser
       || 'root') + ''
   ).replace(/\W/g,'\\$&');
-  
+
   return argv.concat([
     '-o', 'Port=22',
     '-o', 'User=' + user,
