@@ -8,6 +8,7 @@
 var fs = require('fs'),
   path = require('path'),
   vows = require('vows'),
+  utile = require('utile'),
   azureNock = require('../../helpers/azureNock'),
   assert = require('../../helpers/assert'),
   helpers = require('../../helpers');
@@ -16,6 +17,8 @@ var testData    = {},
     testContext = {},
     clients     = {};
 
+var azureOptions = require('../../fixtures/azure/azure-options.json');
+
 function batchOne (providerClient, providerName) {
   var name   = providerName   || 'rackspace',
       client = providerClient || clients['rackspace'],
@@ -69,11 +72,11 @@ function batchTwo (providerClient, providerName) {
       "with image and flavor ids": {
         topic: function () {
           var self = this;
-          client.createServer({
+          client.createServer(utile.mixin({
             name: 'create-test-ids2',
             image: testContext.images[0].id,
-            flavor: testContext.flavors[0].id
-          }, function (err, server) {
+            flavor: testContext.flavors[0].id,
+          }, name === 'azure' ? azureOptions : {}), function (err, server) {
             if (err) { return self.callback(err); }
             server.setWait({ status: 'RUNNING' }, 100*m, function (err, srv) {
               self.callback(null, srv);
@@ -120,7 +123,6 @@ function batchThree (providerClient, providerName) {
         client.destroyServer(server);
         assert.isNull(err);
         assert.assertServerDetails(server);
-        console.log(server.addresses);
         assert.ok(Array.isArray(server.addresses["public"]));
         assert.ok(Array.isArray(server.addresses["private"]));
         assert.ok(typeof server.addresses["private"][0] === 'string');
@@ -142,11 +144,11 @@ function batchReboot(providerClient, providerName, nock) {
     "the rebootServer() method": {
       topic: function () {
         var self = this;
-        client.createServer({
+        client.createServer(utile.mixin({
             name  : "test-reboot", 
             image : testContext.images[0].id,
             flavor: testContext.flavors[0].id
-          },
+          }, name === 'azure' ? azureOptions : {}),
           function (err, server, response) {
             if (err) { return self.callback(err); }
 
@@ -229,7 +231,7 @@ JSON.parse(fs.readFileSync(__dirname + '/../../configs/providers.json'))
     if (process.env.NOCK) {
       if (provider === 'joyent') {
         nock('https://' + client.serversUrl)
-          .get('/' + client.account + '/machines')
+          .get('/' + client.account + '/machines?')
             .reply(200, "[]", {})
           .get('/' + client.account + '/datasets')
             .reply(200, helpers.loadFixture('joyent/images.json'), {})
@@ -340,7 +342,7 @@ JSON.parse(fs.readFileSync(__dirname + '/../../configs/providers.json'))
             'InstanceId': 'i-1d48637b'
           })
             .reply(200,
-                   helpers.loadFixture('amazon/running-server-attr.xml', {}))
+                   helpers.loadFixture('amazon/running-server-attr2.xml', {}))
           .post('/?Action=DescribeInstances', {
             'Filter.1.Name': 'instance-state-code',
             'Filter.1.Value.1': '0',
@@ -437,6 +439,31 @@ JSON.parse(fs.readFileSync(__dirname + '/../../configs/providers.json'))
           })
       } else if(provider === 'azure') {
         azureNock.serverTest(nock, helpers);
+      } else if (provider === 'openstack') {
+        nock(client.authUrl)
+          .post('/v2.0/tokens', "{\"auth\":{\"passwordCredentials\":{\"username\":\"MOCK-USERNAME\",\"password\":\"MOCK-PASSWORD\"}}}")
+            .reply(200, helpers.loadFixture('openstack/initialToken.json'))
+          .get('/v2.0/tenants')
+            .reply(200, helpers.loadFixture('openstack/tenantId.json'))
+          .post('/v2.0/tokens', "{\"auth\":{\"passwordCredentials\":{\"username\":\"MOCK-USERNAME\",\"password\":\"MOCK-PASSWORD\"},\"tenantId\":\"72e90ecb69c44d0296072ea39e537041\"}}")
+            .reply(200, helpers.loadFixture('openstack/realToken.json'));
+
+        nock('http://compute.myownendpoint.org:8774')
+          .get('/v2/72e90ecb69c44d0296072ea39e537041/images/detail')
+            .reply(200, helpers.loadFixture('openstack/images.json'))
+          .get('/v2/72e90ecb69c44d0296072ea39e537041/flavors/detail')
+            .reply(200, helpers.loadFixture('openstack/flavors.json'))
+          .post('/v2/72e90ecb69c44d0296072ea39e537041/servers',
+            "{\"server\":{\"name\":\"create-test-ids2\",\"flavorRef\":1,\"imageRef\":\"506d077e-66bf-44ff-907a-588c5c79fa66\",\"personality\":[],\"key_name\":null}}")
+            .reply(202, helpers.loadFixture('openstack/creatingServer.json'))
+          .get('/v2/72e90ecb69c44d0296072ea39e537041/servers/5a023de8-957b-4822-ad84-8c7a9ef83c07')
+            .reply(200, helpers.loadFixture('openstack/serverCreated2.json'))
+          .get('/v2/72e90ecb69c44d0296072ea39e537041/servers/detail')
+            .reply(200, helpers.loadFixture('openstack/serverList.json'))
+          .get('/v2/72e90ecb69c44d0296072ea39e537041/servers/5a023de8-957b-4822-ad84-8c7a9ef83c07')
+            .reply(200, helpers.loadFixture('openstack/serverCreated2.json'))
+          .delete('/v2/72e90ecb69c44d0296072ea39e537041/servers/5a023de8-957b-4822-ad84-8c7a9ef83c07')
+            .reply(204, "");
       }
     }
     
